@@ -6,16 +6,16 @@ Type annotations for redshift-data service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_redshift_data.type_defs import CancelStatementRequestRequestTypeDef
+    from mypy_boto3_redshift_data.type_defs import BatchExecuteStatementInputRequestTypeDef
 
-    data: CancelStatementRequestRequestTypeDef = {...}
+    data: BatchExecuteStatementInputRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-from .literals import StatusStringType
+from .literals import StatementStatusStringType, StatusStringType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -24,6 +24,8 @@ else:
 
 
 __all__ = (
+    "BatchExecuteStatementInputRequestTypeDef",
+    "BatchExecuteStatementOutputTypeDef",
     "CancelStatementRequestRequestTypeDef",
     "CancelStatementResponseTypeDef",
     "ColumnMetadataTypeDef",
@@ -48,9 +50,50 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "SqlParameterTypeDef",
     "StatementDataTypeDef",
+    "SubStatementDataTypeDef",
     "TableMemberTypeDef",
 )
 
+_RequiredBatchExecuteStatementInputRequestTypeDef = TypedDict(
+    "_RequiredBatchExecuteStatementInputRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "Database": str,
+        "Sqls": List[str],
+    },
+)
+_OptionalBatchExecuteStatementInputRequestTypeDef = TypedDict(
+    "_OptionalBatchExecuteStatementInputRequestTypeDef",
+    {
+        "DbUser": str,
+        "SecretArn": str,
+        "StatementName": str,
+        "WithEvent": bool,
+    },
+    total=False,
+)
+
+
+class BatchExecuteStatementInputRequestTypeDef(
+    _RequiredBatchExecuteStatementInputRequestTypeDef,
+    _OptionalBatchExecuteStatementInputRequestTypeDef,
+):
+    pass
+
+
+BatchExecuteStatementOutputTypeDef = TypedDict(
+    "BatchExecuteStatementOutputTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "CreatedAt": datetime,
+        "Database": str,
+        "DbUser": str,
+        "Id": str,
+        "SecretArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 CancelStatementRequestRequestTypeDef = TypedDict(
     "CancelStatementRequestRequestTypeDef",
     {
@@ -112,6 +155,7 @@ DescribeStatementResponseTypeDef = TypedDict(
         "ResultSize": int,
         "SecretArn": str,
         "Status": StatusStringType,
+        "SubStatements": List["SubStatementDataTypeDef"],
         "UpdatedAt": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -159,13 +203,13 @@ _RequiredExecuteStatementInputRequestTypeDef = TypedDict(
     "_RequiredExecuteStatementInputRequestTypeDef",
     {
         "ClusterIdentifier": str,
+        "Database": str,
         "Sql": str,
     },
 )
 _OptionalExecuteStatementInputRequestTypeDef = TypedDict(
     "_OptionalExecuteStatementInputRequestTypeDef",
     {
-        "Database": str,
         "DbUser": str,
         "Parameters": List["SqlParameterTypeDef"],
         "SecretArn": str,
@@ -245,12 +289,12 @@ _RequiredListDatabasesRequestRequestTypeDef = TypedDict(
     "_RequiredListDatabasesRequestRequestTypeDef",
     {
         "ClusterIdentifier": str,
+        "Database": str,
     },
 )
 _OptionalListDatabasesRequestRequestTypeDef = TypedDict(
     "_OptionalListDatabasesRequestRequestTypeDef",
     {
-        "Database": str,
         "DbUser": str,
         "MaxResults": int,
         "NextToken": str,
@@ -408,8 +452,10 @@ _OptionalStatementDataTypeDef = TypedDict(
     "_OptionalStatementDataTypeDef",
     {
         "CreatedAt": datetime,
+        "IsBatchStatement": bool,
         "QueryParameters": List["SqlParameterTypeDef"],
         "QueryString": str,
+        "QueryStrings": List[str],
         "SecretArn": str,
         "StatementName": str,
         "Status": StatusStringType,
@@ -423,6 +469,34 @@ class StatementDataTypeDef(_RequiredStatementDataTypeDef, _OptionalStatementData
     pass
 
 
+_RequiredSubStatementDataTypeDef = TypedDict(
+    "_RequiredSubStatementDataTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalSubStatementDataTypeDef = TypedDict(
+    "_OptionalSubStatementDataTypeDef",
+    {
+        "CreatedAt": datetime,
+        "Duration": int,
+        "Error": str,
+        "HasResultSet": bool,
+        "QueryString": str,
+        "RedshiftQueryId": int,
+        "ResultRows": int,
+        "ResultSize": int,
+        "Status": StatementStatusStringType,
+        "UpdatedAt": datetime,
+    },
+    total=False,
+)
+
+
+class SubStatementDataTypeDef(_RequiredSubStatementDataTypeDef, _OptionalSubStatementDataTypeDef):
+    pass
+
+
 TableMemberTypeDef = TypedDict(
     "TableMemberTypeDef",
     {
